@@ -3,7 +3,7 @@ use 5.010_000;
 use strict;
 use warnings;
 
-our $VERSION = '0.007';
+our $VERSION = '0.008';
 
 our @EXPORT = qw(all_vars_ok test_vars vars_ok);
 
@@ -192,7 +192,8 @@ sub _check_into_code {
 
     my $cv = B::svref_2object($coderef);
 
-    if($cv->XSUB){
+    # If ROOT is null then the sub is a stub, and has no body for us to check.
+    if($cv->XSUB || $cv->ROOT->isa('B::NULL')){
         return 1;
     }
 
@@ -426,7 +427,7 @@ Test::Vars - Detects unused variables in perl modules
 
 =head1 VERSION
 
-This document describes Test::Vars version 0.007.
+This document describes Test::Vars version 0.008.
 
 =head1 SYNOPSIS
 
